==> zio-aws-cloudformation_2.12-5.17.129.3-sources.jar: zio/aws/cloudformation/model/DetectStackSetDriftResponse.scala <==
package zio.aws.cloudformation.model
import zio.aws.cloudformation.model.primitives.ClientRequestToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DetectStackSetDriftResponse(
    operationId: Option[ClientRequestToken] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse = {
    import DetectStackSetDriftResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
      .builder()
      .optionallyWith(
        operationId.map(value =>
          ClientRequestToken.unwrap(value): java.lang.String
        )
      )(_.operationId)
      .build()
  }
  def asReadOnly
      : zio.aws.cloudformation.model.DetectStackSetDriftResponse.ReadOnly =
    zio.aws.cloudformation.model.DetectStackSetDriftResponse
      .wrap(buildAwsValue())
}
object DetectStackSetDriftResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.DetectStackSetDriftResponse =
      zio.aws.cloudformation.model
        .DetectStackSetDriftResponse(operationId.map(value => value))
    def operationId: Option[ClientRequestToken]
    def getOperationId: ZIO[Any, AwsError, ClientRequestToken] =
      AwsError.unwrapOptionField("operationId", operationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
  ) extends zio.aws.cloudformation.model.DetectStackSetDriftResponse.ReadOnly {
    override val operationId: Option[ClientRequestToken] = scala
      .Option(impl.operationId())
      .map(value =>
        zio.aws.cloudformation.model.primitives.ClientRequestToken(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
  ): zio.aws.cloudformation.model.DetectStackSetDriftResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-cloudformation_2.12-5.17.177.1-sources.jar: zio/aws/cloudformation/model/DetectStackSetDriftResponse.scala <==
package zio.aws.cloudformation.model
import zio.aws.cloudformation.model.primitives.ClientRequestToken
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DetectStackSetDriftResponse(
    operationId: Optional[ClientRequestToken] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse = {
    import DetectStackSetDriftResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
      .builder()
      .optionallyWith(
        operationId.map(value =>
          ClientRequestToken.unwrap(value): java.lang.String
        )
      )(_.operationId)
      .build()
  }
  def asReadOnly
      : zio.aws.cloudformation.model.DetectStackSetDriftResponse.ReadOnly =
    zio.aws.cloudformation.model.DetectStackSetDriftResponse
      .wrap(buildAwsValue())
}
object DetectStackSetDriftResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.cloudformation.model.DetectStackSetDriftResponse =
      zio.aws.cloudformation.model
        .DetectStackSetDriftResponse(operationId.map(value => value))
    def operationId: Optional[ClientRequestToken]
    def getOperationId: ZIO[Any, AwsError, ClientRequestToken] =
      AwsError.unwrapOptionField("operationId", operationId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
  ) extends zio.aws.cloudformation.model.DetectStackSetDriftResponse.ReadOnly {
    override val operationId: Optional[ClientRequestToken] =
      zio.aws.core.internal
        .optionalFromNullable(impl.operationId())
        .map(value =>
          zio.aws.cloudformation.model.primitives.ClientRequestToken(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.cloudformation.model.DetectStackSetDriftResponse
  ): zio.aws.cloudformation.model.DetectStackSetDriftResponse.ReadOnly =
    new Wrapper(impl)
}
